# Reference

## chardetng_py

```{eval-rst}
.. automodule:: chardetng_py
   :members:
   :undoc-members:
```

## chardetng_py.compat

```{eval-rst}
.. automodule:: chardetng_py.compat
   :members:
   :undoc-members:
```
